package com.example.apitest

import android.graphics.BitmapFactory
import android.os.Bundle
import android.util.Log
import android.view.LayoutInflater
import android.view.ViewGroup
import androidx.appcompat.app.AppCompatActivity
import androidx.appcompat.widget.SearchView
import androidx.recyclerview.widget.LinearLayoutManager
import androidx.recyclerview.widget.RecyclerView
import com.example.apitest.API.APIConnection
import com.example.apitest.API.APIConnectionMain
import com.example.apitest.API.Catalog
import com.example.apitest.API.News
import com.example.apitest.API.Order
import com.example.apitest.API.User
import com.example.apitest.databinding.ActivityMainBinding
import com.example.apitest.databinding.PinkyPieLayoutBinding
import com.google.gson.JsonObject
import com.squareup.picasso.Picasso
import retrofit2.Call
import retrofit2.Callback
import retrofit2.Response
import java.net.URL


class MainActivity : AppCompatActivity() {

    var _binding : ActivityMainBinding? = null;

    val binding : ActivityMainBinding
        get() = _binding!!

    var NewsCollection : MutableList<News> = mutableListOf()

    var NewsCollectionAfterChanged : MutableList<News> = mutableListOf()

    var NewsCollectionAdapter : RecyclerViewMainAdapterDUPER? = null;

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        _binding = ActivityMainBinding.inflate(layoutInflater)
        setContentView(binding.root)
        APIConnection.getRetrofit().GetAllNews().enqueue(object : Callback<MutableList<News>> {
            override fun onResponse(
                call: Call<MutableList<News>>,
                response: Response<MutableList<News>>
            ) {
                NewsCollection.addAll(response.body()!!);
                NewsCollectionAfterChanged.addAll(response.body()!!)
                setRecyclerView();

            }

            override fun onFailure(call: Call<MutableList<News>>, t: Throwable) {
                Log.println(Log.INFO, "problem", "Произошла ошибка при отправке запроса");
            }
        })

        binding.MainSearchView.setOnQueryTextListener(object : SearchView.OnQueryTextListener{

            override fun onQueryTextSubmit(query: String?): Boolean {
                return true
            }

            override fun onQueryTextChange(newText: String?): Boolean {
                NewsCollectionAfterChanged.clear()
                for (item in NewsCollection)
                {
                    if(item.name!!.contains(newText!!, true)) {
                        NewsCollectionAfterChanged.add(item)
                    }
                }
                NewsCollectionAdapter!!.notifyDataSetChanged()
                return true;
            }

        })

        /*
        var user : User = User(10, "TestAndroid", "TestAndroid", "TestAndroid"
            , "TestAndroid", "TestAndroid","TestAndroid", 1)
        APIConnectionMain.getRetrofit().PostUser(user).enqueue(object : Callback<JsonObject>{

            override fun onResponse(call: Call<JsonObject>, response: Response<JsonObject>) {
                Log.println(Log.INFO, "API", response.code().toString())
            }

            override fun onFailure(call: Call<JsonObject>, t: Throwable) {
                Log.println(Log.WARN, "API", "Всё пропало!")
                Log.println(Log.WARN, "API", t.message.toString())
            }

        })
        */
    }

    fun setRecyclerView() {
        binding.RecyclerViewMain.layoutManager =
            LinearLayoutManager( this
                                        , LinearLayoutManager.VERTICAL
                                        , false)
        NewsCollectionAdapter = RecyclerViewMainAdapterDUPER(NewsCollectionAfterChanged)
        binding.RecyclerViewMain.adapter = NewsCollectionAdapter

    }
}

class RecyclerViewMainAdapterDUPER(var itemCollection: MutableList<News>) : RecyclerView.Adapter<RecyclerViewMainViewHolderDUPER>() {
    override fun onCreateViewHolder(
        parent: ViewGroup,
        viewType: Int
    ): RecyclerViewMainViewHolderDUPER {
        return RecyclerViewMainViewHolderDUPER(PinkyPieLayoutBinding.inflate(LayoutInflater.from(parent.context)));
    }

    override fun getItemCount(): Int {
        return itemCollection.size;
    }

    override fun onBindViewHolder(holder: RecyclerViewMainViewHolderDUPER, position: Int) {
        holder.binding.id.text = itemCollection[position].id.toString();
        holder.binding.name.text = itemCollection[position].name.toString();
        holder.binding.description.text = itemCollection[position].description.toString();
        holder.binding.price.text = itemCollection[position].price.toString();
        Picasso.get().load(itemCollection[position].image!!.replace("http", "https")).into(holder.binding.blall);
    }

}

class RecyclerViewMainViewHolderDUPER(var binding: PinkyPieLayoutBinding)
    : RecyclerView.ViewHolder(binding.root)